"use strict";

var _utils = require("../../../../../tests/utils");

var _InMemoryCache = _interopRequireDefault(require("../InMemoryCache"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

it('should create a default cache', function () {
  var cache = new _InMemoryCache.default();
  expect(cache).toMatchSnapshot();
});
it('should create a custom cache', function () {
  var cache = new _InMemoryCache.default({
    size: 100,
    ttl: 100
  });
  expect(cache).toMatchSnapshot();
});
it('should set and get an item', function () {
  var cache = new _InMemoryCache.default();
  var queryID = 'queryID';
  var variables = {};
  var data = {
    data: 'data'
  };
  cache.set(queryID, variables, data);
  expect(cache.get(queryID, variables)).toBe(data);
});
it('should clear the cache', function () {
  var cache = new _InMemoryCache.default();
  var queryID = 'queryID';
  var variables = {};
  var data = {
    data: 'data'
  };
  cache.set(queryID, variables, data);
  cache.clear();
  expect(cache.store._responses.size).toBe(0);
});
it('should handle size', function () {
  var cache = new _InMemoryCache.default({
    size: 1
  });
  var firstQueryID = 'firstQueryID';
  var firstVariables = {};
  var firstData = {
    data: 'firstData'
  };
  cache.set(firstQueryID, firstVariables, firstData);
  var secondQueryID = 'secondQueryID';
  var secondVariables = {};
  var secondData = {
    data: 'secondData'
  };
  cache.set(secondQueryID, secondVariables, secondData);
  expect(cache.store._responses.size).toBe(1);
});
it('should handle ttl',
/*#__PURE__*/
_asyncToGenerator(
/*#__PURE__*/
regeneratorRuntime.mark(function _callee() {
  var cache, queryID, variables, data;
  return regeneratorRuntime.wrap(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          cache = new _InMemoryCache.default({
            ttl: 10
          });
          queryID = 'queryID';
          variables = {};
          data = {
            data: 'data'
          };
          cache.set(queryID, variables, data);
          expect(cache.get(queryID, variables)).toBe(data);
          _context.next = 8;
          return (0, _utils.delay)(100);

        case 8:
          expect(cache.get(queryID, variables)).toBe(null);

        case 9:
        case "end":
          return _context.stop();
      }
    }
  }, _callee, this);
})));
//# sourceMappingURL=InMemoryCache.spec.js.map