"use strict";

var _core = require("../../../../tests/fixtures/core");

var _relay = require("../../../../tests/fixtures/relay");

var _utils = require("../../../../tests/utils");

var _constants = require("../../../utils/constants");

var _utils2 = require("../../../relay/utils");

var _InMemoryCache = _interopRequireDefault(require("../../../core/cache/InMemoryCache/InMemoryCache"));

var _createNetwork = _interopRequireDefault(require("../createNetwork"));

var _CacheResolver = _interopRequireDefault(require("../CacheResolver"));

var _FetchResolver = _interopRequireDefault(require("../FetchResolver"));

var _SSRResolver = _interopRequireDefault(require("../SSRResolver"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

beforeEach(function () {
  jest.clearAllMocks();
});
it('should create default Network', function () {
  var config = (0, _core.createConfig)();
  var network = (0, _createNetwork.default)(config);
  expect(network).toMatchSnapshot();
});
it('should create Network with networkLogger', function () {
  var config = (0, _core.createConfig)({
    networkLogger: true
  });
  var network = (0, _createNetwork.default)(config);
  expect(network).toMatchSnapshot();
});
it('should create Network with cache', function () {
  var config = (0, _core.createConfig)({
    cache: new _InMemoryCache.default()
  });
  var network = (0, _createNetwork.default)(config);
  expect(network).toMatchSnapshot();
});
it('should resolve with SSR',
/*#__PURE__*/
_asyncToGenerator(
/*#__PURE__*/
regeneratorRuntime.mark(function _callee() {
  var ssrResolver, cacheResolver, fetchResolver, request, variables, cacheConfig, response, config, network;
  return regeneratorRuntime.wrap(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          ssrResolver = jest.spyOn(_SSRResolver.default.prototype, 'resolve');
          cacheResolver = jest.spyOn(_CacheResolver.default.prototype, 'resolve');
          fetchResolver = jest.spyOn(_FetchResolver.default.prototype, 'resolve');
          request = (0, _relay.createQueryRequest)();
          variables = {};
          cacheConfig = (0, _relay.createCacheConfig)();
          response = (0, _relay.createQueryResponse)();
          window[_constants.WINDOW_DATA_KEY] = _defineProperty({}, (0, _utils2.getHash)(request, variables), response.data); // make sure this is being created after releasy data is populated

          config = (0, _core.createConfig)();
          network = (0, _createNetwork.default)(config);
          network.execute(request, variables, cacheConfig);
          expect(ssrResolver).toHaveBeenCalled();
          expect(cacheResolver).not.toHaveBeenCalled();
          expect(fetchResolver).not.toHaveBeenCalled();

        case 14:
        case "end":
          return _context.stop();
      }
    }
  }, _callee, this);
})));
it('should resolve with cache',
/*#__PURE__*/
_asyncToGenerator(
/*#__PURE__*/
regeneratorRuntime.mark(function _callee2() {
  var ssrResolver, cacheResolver, fetchResolver, config, network, request, variables, cacheConfig;
  return regeneratorRuntime.wrap(function _callee2$(_context2) {
    while (1) {
      switch (_context2.prev = _context2.next) {
        case 0:
          ssrResolver = jest.spyOn(_SSRResolver.default.prototype, 'resolve');
          cacheResolver = jest.spyOn(_CacheResolver.default.prototype, 'resolve');
          fetchResolver = jest.spyOn(_FetchResolver.default.prototype, 'resolve');
          config = (0, _core.createConfig)({
            cache: new _InMemoryCache.default()
          });
          network = (0, _createNetwork.default)(config);
          request = (0, _relay.createQueryRequest)();
          variables = {};
          cacheConfig = (0, _relay.createCacheConfig)();
          global.fetch.mockResponseOnce(JSON.stringify((0, _relay.createQueryResponse)()), {
            status: 200,
            headers: {
              'content-type': 'application/json'
            }
          });
          network.execute(request, variables, cacheConfig);
          _context2.next = 12;
          return (0, _utils.delay)(100);

        case 12:
          network.execute(request, variables, cacheConfig); // first call will bypass ssr and cache

          expect(ssrResolver).toHaveBeenCalledTimes(2);
          expect(cacheResolver).toHaveBeenCalledTimes(2);
          expect(fetchResolver).toHaveBeenCalledTimes(1);

        case 16:
        case "end":
          return _context2.stop();
      }
    }
  }, _callee2, this);
})));
it('shouldn\'t resolve with cache and also clear the cache on mutations',
/*#__PURE__*/
_asyncToGenerator(
/*#__PURE__*/
regeneratorRuntime.mark(function _callee3() {
  var ssrResolver, cacheResolver, fetchResolver, config, network, queryRequest, queryVariables, queryCacheConfig, mutationRequest, mutationVariables, mutationCacheConfig;
  return regeneratorRuntime.wrap(function _callee3$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          ssrResolver = jest.spyOn(_SSRResolver.default.prototype, 'resolve');
          cacheResolver = jest.spyOn(_CacheResolver.default.prototype, 'resolve');
          fetchResolver = jest.spyOn(_FetchResolver.default.prototype, 'resolve');
          config = (0, _core.createConfig)({
            cache: new _InMemoryCache.default()
          });
          network = (0, _createNetwork.default)(config);
          queryRequest = (0, _relay.createQueryRequest)();
          queryVariables = {};
          queryCacheConfig = (0, _relay.createCacheConfig)();
          global.fetch.mockResponseOnce(JSON.stringify((0, _relay.createQueryResponse)()), {
            status: 200,
            headers: {
              'content-type': 'application/json'
            }
          });
          network.execute(queryRequest, queryVariables, queryCacheConfig);
          _context3.next = 12;
          return (0, _utils.delay)(100);

        case 12:
          expect(config.cache.size()).toBe(1);
          mutationRequest = (0, _relay.createMutationRequest)();
          mutationVariables = {};
          mutationCacheConfig = (0, _relay.createCacheConfig)();
          global.fetch.mockResponseOnce(JSON.stringify((0, _relay.createMutationResponse)()), {
            status: 200,
            headers: {
              'content-type': '*/*'
            }
          });
          network.execute(mutationRequest, mutationVariables, mutationCacheConfig);
          expect(ssrResolver).toHaveBeenCalledTimes(2);
          expect(cacheResolver).toHaveBeenCalledTimes(2);
          expect(fetchResolver).toHaveBeenCalledTimes(2);
          expect(config.cache.size()).toBe(0);

        case 22:
        case "end":
          return _context3.stop();
      }
    }
  }, _callee3, this);
})));
//# sourceMappingURL=createNetwork.spec.js.map