"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _relayRuntime = require("relay-runtime");

var _CacheResolver = _interopRequireDefault(require("./CacheResolver"));

var _FetchResolver = _interopRequireDefault(require("./FetchResolver"));

var _SSRResolver = _interopRequireDefault(require("./SSRResolver"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var createNetwork = function createNetwork(config) {
  var resolvers = [new _SSRResolver.default(), new _CacheResolver.default(config), new _FetchResolver.default(config)];
  return _relayRuntime.Network.create(function (request, variables, cacheConfig, uploadables) {
    return new Promise(function (resolve, reject) {
      var sink;
      var data;
      var currentResolver = -1;

      _relayRuntime.Observable.create(function (_sink) {
        sink = _sink;

        _sink.next();
      }).subscribe({
        next: function next(_data) {
          if (_data) {
            data = _data;
            return;
          }

          currentResolver += 1;
          var resolver = resolvers[currentResolver];

          if (!resolver) {
            sink.complete();
            return;
          }

          resolver.resolve(request, variables, cacheConfig, uploadables, sink);
        },
        complete: function complete() {
          return resolve(data);
        },
        error: reject
      });
    });
  });
};

var _default = createNetwork;
exports.default = _default;
//# sourceMappingURL=createNetwork.js.map