"use strict";

var React = _interopRequireWildcard(require("react"));

var _components = require("../../../tests/components");

var _core = require("../../../tests/fixtures/core");

var _relay = require("../../../tests/fixtures/relay");

var _ReleasyProvider = _interopRequireDefault(require("../../components/ReleasyProvider"));

var _getDataFromTree = _interopRequireWildcard(require("../getDataFromTree"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

it('should identify context', function () {
  var initialValue = {
    name: 'John'
  };
  var MyContext = React.createContext(initialValue);
  expect((0, _getDataFromTree.identifyComponentType)(React.createElement(MyContext.Provider, {
    value: initialValue
  }, React.createElement("div", null)))).toBe(_getDataFromTree.ComponentType.CONTEXT_PROVIDER);
  expect((0, _getDataFromTree.identifyComponentType)(React.createElement(MyContext.Consumer, null, function () {
    return React.createElement("div", null);
  }))).toBe(_getDataFromTree.ComponentType.CONTEXT_CONSUMER);
});
it('should identify class component', function () {
  var MyComponent =
  /*#__PURE__*/
  function (_React$Component) {
    _inherits(MyComponent, _React$Component);

    function MyComponent() {
      _classCallCheck(this, MyComponent);

      return _possibleConstructorReturn(this, _getPrototypeOf(MyComponent).apply(this, arguments));
    }

    _createClass(MyComponent, [{
      key: "render",
      value: function render() {
        return this.props.children;
      }
    }]);

    return MyComponent;
  }(React.Component);

  expect((0, _getDataFromTree.identifyComponentType)(React.createElement(MyComponent, null, React.createElement("div", null)))).toBe(_getDataFromTree.ComponentType.CLASS_COMPONENT);
});
it('should identify stateless component', function () {
  var MyComponent = function MyComponent(props) {
    return props.children;
  };

  expect((0, _getDataFromTree.identifyComponentType)(React.createElement(MyComponent, null, React.createElement("div", null)))).toBe(_getDataFromTree.ComponentType.STATELESS_COMPONENT);
});
it('should identify dom elements', function () {
  expect((0, _getDataFromTree.identifyComponentType)(React.createElement("div", null))).toBe(_getDataFromTree.ComponentType.DOM_ELEMENT);
  expect((0, _getDataFromTree.identifyComponentType)(React.createElement("span", null))).toBe(_getDataFromTree.ComponentType.DOM_ELEMENT);
  expect((0, _getDataFromTree.identifyComponentType)(React.createElement("p", null))).toBe(_getDataFromTree.ComponentType.DOM_ELEMENT);
});
it('should walk context',
/*#__PURE__*/
_asyncToGenerator(
/*#__PURE__*/
regeneratorRuntime.mark(function _callee() {
  var initialValue, realValue, MyContext, components;
  return regeneratorRuntime.wrap(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          initialValue = {
            name: 'John'
          };
          realValue = {
            name: 'Doe'
          };
          MyContext = React.createContext(initialValue);
          components = [];
          _context.next = 6;
          return (0, _getDataFromTree.walkTree)(React.createElement(MyContext.Provider, {
            value: realValue
          }, React.createElement(MyContext.Consumer, null, function (anotherValue) {
            expect(anotherValue).toBe(realValue);
            return [React.createElement("div", null), React.createElement("div", null)];
          })), {}, function (element) {
            var componentType = (0, _getDataFromTree.identifyComponentType)(element);
            components.push(componentType);
          });

        case 6:
          expect(components).toMatchSnapshot();

        case 7:
        case "end":
          return _context.stop();
      }
    }
  }, _callee, this);
})));
it('should walk class component',
/*#__PURE__*/
_asyncToGenerator(
/*#__PURE__*/
regeneratorRuntime.mark(function _callee2() {
  var MyComponent, components;
  return regeneratorRuntime.wrap(function _callee2$(_context2) {
    while (1) {
      switch (_context2.prev = _context2.next) {
        case 0:
          MyComponent =
          /*#__PURE__*/
          function (_React$Component2) {
            _inherits(MyComponent, _React$Component2);

            function MyComponent() {
              _classCallCheck(this, MyComponent);

              return _possibleConstructorReturn(this, _getPrototypeOf(MyComponent).apply(this, arguments));
            }

            _createClass(MyComponent, [{
              key: "render",
              value: function render() {
                return React.createElement("div", null);
              }
            }]);

            return MyComponent;
          }(React.Component);

          components = [];
          _context2.next = 4;
          return (0, _getDataFromTree.walkTree)(React.createElement(MyComponent, null), {}, function (element) {
            var componentType = (0, _getDataFromTree.identifyComponentType)(element);
            components.push(componentType);
          });

        case 4:
          expect(components).toMatchSnapshot();

        case 5:
        case "end":
          return _context2.stop();
      }
    }
  }, _callee2, this);
})));
it('should walk class component with getDerivedStateFromProps',
/*#__PURE__*/
_asyncToGenerator(
/*#__PURE__*/
regeneratorRuntime.mark(function _callee3() {
  var MyComponent, components;
  return regeneratorRuntime.wrap(function _callee3$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          MyComponent =
          /*#__PURE__*/
          function (_React$Component3) {
            _inherits(MyComponent, _React$Component3);

            function MyComponent() {
              _classCallCheck(this, MyComponent);

              return _possibleConstructorReturn(this, _getPrototypeOf(MyComponent).apply(this, arguments));
            }

            _createClass(MyComponent, [{
              key: "render",
              value: function render() {
                return React.createElement("div", null);
              }
            }], [{
              key: "getDerivedStateFromProps",
              value: function getDerivedStateFromProps() {
                return {
                  name: 'John'
                };
              }
            }]);

            return MyComponent;
          }(React.Component);

          components = [];
          _context3.next = 4;
          return (0, _getDataFromTree.walkTree)(React.createElement(MyComponent, null), {}, function (element) {
            var componentType = (0, _getDataFromTree.identifyComponentType)(element);
            components.push(componentType);
          });

        case 4:
          expect(components).toMatchSnapshot();

        case 5:
        case "end":
          return _context3.stop();
      }
    }
  }, _callee3, this);
})));
it('should walk class component with UNSAFE_componentWillMount',
/*#__PURE__*/
_asyncToGenerator(
/*#__PURE__*/
regeneratorRuntime.mark(function _callee4() {
  var MyComponent, components;
  return regeneratorRuntime.wrap(function _callee4$(_context4) {
    while (1) {
      switch (_context4.prev = _context4.next) {
        case 0:
          MyComponent =
          /*#__PURE__*/
          function (_React$Component4) {
            _inherits(MyComponent, _React$Component4);

            function MyComponent() {
              _classCallCheck(this, MyComponent);

              return _possibleConstructorReturn(this, _getPrototypeOf(MyComponent).apply(this, arguments));
            }

            _createClass(MyComponent, [{
              key: "UNSAFE_componentWillMount",
              value: function UNSAFE_componentWillMount() {
                this.setState({
                  name: 'John'
                });
              }
            }, {
              key: "render",
              value: function render() {
                return React.createElement("div", null);
              }
            }]);

            return MyComponent;
          }(React.Component);

          components = [];
          _context4.next = 4;
          return (0, _getDataFromTree.walkTree)(React.createElement(MyComponent, null), {}, function (element) {
            var componentType = (0, _getDataFromTree.identifyComponentType)(element);
            components.push(componentType);
          });

        case 4:
          expect(components).toMatchSnapshot();

        case 5:
        case "end":
          return _context4.stop();
      }
    }
  }, _callee4, this);
})));
it('should walk class component with componentWillMount',
/*#__PURE__*/
_asyncToGenerator(
/*#__PURE__*/
regeneratorRuntime.mark(function _callee5() {
  var MyComponent, components;
  return regeneratorRuntime.wrap(function _callee5$(_context5) {
    while (1) {
      switch (_context5.prev = _context5.next) {
        case 0:
          MyComponent =
          /*#__PURE__*/
          function (_React$Component5) {
            _inherits(MyComponent, _React$Component5);

            function MyComponent() {
              _classCallCheck(this, MyComponent);

              return _possibleConstructorReturn(this, _getPrototypeOf(MyComponent).apply(this, arguments));
            }

            _createClass(MyComponent, [{
              key: "componentWillMount",
              value: function componentWillMount() {
                this.setState(function () {
                  return {
                    name: 'John'
                  };
                });
              }
            }, {
              key: "render",
              value: function render() {
                return React.createElement("div", null);
              }
            }]);

            return MyComponent;
          }(React.Component);

          components = [];
          _context5.next = 4;
          return (0, _getDataFromTree.walkTree)(React.createElement(MyComponent, null), {}, function (element) {
            var componentType = (0, _getDataFromTree.identifyComponentType)(element);
            components.push(componentType);
          });

        case 4:
          expect(components).toMatchSnapshot();

        case 5:
        case "end":
          return _context5.stop();
      }
    }
  }, _callee5, this);
})));
it('should walk stateless component',
/*#__PURE__*/
_asyncToGenerator(
/*#__PURE__*/
regeneratorRuntime.mark(function _callee6() {
  var MyComponent, components;
  return regeneratorRuntime.wrap(function _callee6$(_context6) {
    while (1) {
      switch (_context6.prev = _context6.next) {
        case 0:
          MyComponent = function MyComponent() {
            return React.createElement("div", null);
          };

          components = [];
          _context6.next = 4;
          return (0, _getDataFromTree.walkTree)(React.createElement(MyComponent, null), {}, function (element) {
            var componentType = (0, _getDataFromTree.identifyComponentType)(element);
            components.push(componentType);
          });

        case 4:
          expect(components).toMatchSnapshot();

        case 5:
        case "end":
          return _context6.stop();
      }
    }
  }, _callee6, this);
})));
it('should get data from tree',
/*#__PURE__*/
_asyncToGenerator(
/*#__PURE__*/
regeneratorRuntime.mark(function _callee7() {
  var config, result;
  return regeneratorRuntime.wrap(function _callee7$(_context7) {
    while (1) {
      switch (_context7.prev = _context7.next) {
        case 0:
          global.fetch.mockResponse(JSON.stringify((0, _relay.createQueryResponse)()), {
            status: 200,
            headers: {
              'content-type': 'application/json'
            }
          });
          config = (0, _core.createConfig)();
          _context7.next = 4;
          return (0, _getDataFromTree.default)(React.createElement(_ReleasyProvider.default, {
            config: config
          }, React.createElement(_components.MeQuery, null)));

        case 4:
          result = _context7.sent;
          expect(result).toMatchSnapshot();

        case 6:
        case "end":
          return _context7.stop();
      }
    }
  }, _callee7, this);
})));
//# sourceMappingURL=getDataFromTree.spec.js.map