"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.walkTree = exports.identifyComponentType = exports.ComponentType = void 0;

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var ComponentType;
exports.ComponentType = ComponentType;

(function (ComponentType) {
  ComponentType["CONTEXT_PROVIDER"] = "React.Provider";
  ComponentType["CONTEXT_CONSUMER"] = "React.Consumer";
  ComponentType["CLASS_COMPONENT"] = "React.ComponentClass";
  ComponentType["STATELESS_COMPONENT"] = "React.SFC";
  ComponentType["DOM_ELEMENT"] = "React.DOMElement";
})(ComponentType || (exports.ComponentType = ComponentType = {}));

var isContextProvider = function isContextProvider(element) {
  var type = element.type;
  return !!type && !!type._context && !type.Consumer;
};

var isContextConsumer = function isContextConsumer(element) {
  var type = element.type;
  return !!type && !!type.Consumer;
};

var isClassComponent = function isClassComponent(element) {
  var type = element.type;
  return !!type && type.prototype && (type.prototype.isReactComponent || type.prototype.isPureReactComponent);
};

var isStatelessComponent = function isStatelessComponent(element) {
  var type = element.type;
  return !!type && typeof type === 'function';
};

var isDOMElement = function isDOMElement(element) {
  return !isContextProvider(element) && !isContextConsumer(element) && !isClassComponent(element) && !isStatelessComponent(element);
};

var identifyComponentType = function identifyComponentType(element) {
  var _rules;

  var rules = (_rules = {}, _defineProperty(_rules, ComponentType.CONTEXT_PROVIDER, isContextProvider), _defineProperty(_rules, ComponentType.CONTEXT_CONSUMER, isContextConsumer), _defineProperty(_rules, ComponentType.CLASS_COMPONENT, isClassComponent), _defineProperty(_rules, ComponentType.STATELESS_COMPONENT, isStatelessComponent), _defineProperty(_rules, ComponentType.DOM_ELEMENT, isDOMElement), _rules);
  return Object.keys(ComponentType).reduce(function (accumulator, key) {
    var value = ComponentType[key];
    var rule = rules[value];

    if (accumulator || !rule(element)) {
      return accumulator;
    }

    return value;
  }, null);
};

exports.identifyComponentType = identifyComponentType;

var handleContextProvider =
/*#__PURE__*/
function () {
  var _ref = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee(element, context, visitor) {
    var type, props, currentValue;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            type = element.type;
            props = element.props;
            currentValue = props.value || {};
            type._context.currentValue = currentValue;
            _context.next = 6;
            return visitor(element, null);

          case 6:
            return _context.abrupt("return", walkTree(props.children, context, visitor));

          case 7:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function handleContextProvider(_x, _x2, _x3) {
    return _ref.apply(this, arguments);
  };
}();

var handleContextConsumer =
/*#__PURE__*/
function () {
  var _ref2 = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee2(element, context, visitor) {
    var type, props;
    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            type = element.type;
            props = element.props;
            _context2.next = 4;
            return visitor(element, null);

          case 4:
            return _context2.abrupt("return", walkTree(props.children(type.currentValue), context, visitor));

          case 5:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2, this);
  }));

  return function handleContextConsumer(_x4, _x5, _x6) {
    return _ref2.apply(this, arguments);
  };
}();

var handleClassComponent =
/*#__PURE__*/
function () {
  var _ref3 = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee3(element, context, visitor) {
    var type, props, instance, newState, newContext;
    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            type = element.type;
            props = _objectSpread({}, type.defaultProps, element.props);
            instance = new type(props, context);
            instance.context = instance.context || context;
            instance.state = instance.state || null;

            instance.setState = function (state) {
              var newState = typeof state === 'function' ? state(instance.state, instance.props) : state;
              instance.state = _objectSpread({}, instance.state, newState);
            };

            if (type.getDerivedStateFromProps) {
              newState = type.getDerivedStateFromProps(instance.props, instance.state);
              instance.state = _objectSpread({}, instance.state, newState);
            } else if (instance.UNSAFE_componentWillMount) {
              instance.UNSAFE_componentWillMount();
            } else if (instance.componentWillMount) {
              instance.componentWillMount();
            }

            newContext = instance.getChildContext ? _objectSpread({}, context, instance.getChildContext()) : context;
            _context3.next = 10;
            return visitor(element, instance);

          case 10:
            return _context3.abrupt("return", walkTree(instance.render(), newContext, visitor));

          case 11:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3, this);
  }));

  return function handleClassComponent(_x7, _x8, _x9) {
    return _ref3.apply(this, arguments);
  };
}();

var handleStatelessComponent =
/*#__PURE__*/
function () {
  var _ref4 = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee4(element, context, visitor) {
    var type, props;
    return regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            type = element.type;
            props = _objectSpread({}, type.defaultProps, element.props);
            _context4.next = 4;
            return visitor(element, null);

          case 4:
            return _context4.abrupt("return", walkTree(type(props), context, visitor));

          case 5:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4, this);
  }));

  return function handleStatelessComponent(_x10, _x11, _x12) {
    return _ref4.apply(this, arguments);
  };
}();

var handleDOMElement =
/*#__PURE__*/
function () {
  var _ref5 = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee5(element, context, visitor) {
    var props;
    return regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            props = element.props || {};
            _context5.next = 3;
            return visitor(element, null);

          case 3:
            return _context5.abrupt("return", walkTree(props.children, context, visitor));

          case 4:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5, this);
  }));

  return function handleDOMElement(_x13, _x14, _x15) {
    return _ref5.apply(this, arguments);
  };
}();

var walkTree = function walkTree(element) {
  var _handlers;

  var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var visitor = arguments.length > 2 ? arguments[2] : undefined;

  if (!element) {
    return;
  }

  if (Array.isArray(element)) {
    return Promise.all(element.map(function (item) {
      return walkTree(item, context, visitor);
    }));
  }

  var handlers = (_handlers = {}, _defineProperty(_handlers, ComponentType.CONTEXT_PROVIDER, handleContextProvider), _defineProperty(_handlers, ComponentType.CONTEXT_CONSUMER, handleContextConsumer), _defineProperty(_handlers, ComponentType.CLASS_COMPONENT, handleClassComponent), _defineProperty(_handlers, ComponentType.STATELESS_COMPONENT, handleStatelessComponent), _defineProperty(_handlers, ComponentType.DOM_ELEMENT, handleDOMElement), _handlers);
  var componentType = identifyComponentType(element);
  var handler = handlers[componentType];
  return handler(element, context, visitor);
};

exports.walkTree = walkTree;

var resolveRelayQueryRenderer = function resolveRelayQueryRenderer(instance) {
  var _instance$props = instance.props,
      environment = _instance$props.environment,
      query = _instance$props.query,
      variables = _instance$props.variables;
  var getRequest = environment.unstable_internal.getRequest;
  var request = getRequest(query);
  var queryFetcher = instance.state.queryFetcher;
  return new Promise(function (resolve, reject) {
    if (queryFetcher._snapshot) {
      return resolve({
        request: request,
        variables: variables,
        data: queryFetcher._snapshot.data
      });
    }

    queryFetcher._fetchOptions.onDataChangeCallbacks.push(function (_ref6) {
      var error = _ref6.error,
          snapshot = _ref6.snapshot;

      if (error) {
        return reject(error);
      }

      resolve({
        request: request,
        variables: variables,
        data: snapshot.data
      });
    });
  });
};

var getDataFromTree =
/*#__PURE__*/
function () {
  var _ref7 = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee7(rootElement) {
    var rootContext,
        promises,
        _args7 = arguments;
    return regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            rootContext = _args7.length > 1 && _args7[1] !== undefined ? _args7[1] : {};
            promises = [];
            _context7.next = 4;
            return walkTree(rootElement, rootContext,
            /*#__PURE__*/
            function () {
              var _ref8 = _asyncToGenerator(
              /*#__PURE__*/
              regeneratorRuntime.mark(function _callee6(element, instance) {
                var _ref9, type, promise;

                return regeneratorRuntime.wrap(function _callee6$(_context6) {
                  while (1) {
                    switch (_context6.prev = _context6.next) {
                      case 0:
                        _ref9 = element, type = _ref9.type;

                        if (!(!type || type.name !== 'ReactRelayQueryRenderer')) {
                          _context6.next = 3;
                          break;
                        }

                        return _context6.abrupt("return");

                      case 3:
                        promise = resolveRelayQueryRenderer(instance);
                        promises.push(promise);

                      case 5:
                      case "end":
                        return _context6.stop();
                    }
                  }
                }, _callee6, this);
              }));

              return function (_x17, _x18) {
                return _ref8.apply(this, arguments);
              };
            }());

          case 4:
            return _context7.abrupt("return", Promise.all(promises));

          case 5:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7, this);
  }));

  return function getDataFromTree(_x16) {
    return _ref7.apply(this, arguments);
  };
}();

var _default = getDataFromTree;
exports.default = _default;
//# sourceMappingURL=getDataFromTree.js.map